@@ -2,14 +2,11 @@
 
 import functools
 import inspect
-
 import web.core
-import webob.exc
+
 from paste.registry import StackedObjectProxy
-
-import middleware
-
-from predicates import *
+from web.auth import middleware, predicates
+from web.auth.predicates import *
 
 
 __all__ = ['config', 'user', 'authenticate', 'deauthenticate', 'authorize'] + predicates.__all__
@@ -18,9 +15,8 @@ log = __import__('logging').getLogger(__name__)
 config = None
 user = StackedObjectProxy(name="user")
 
-web.core.namespace['web'].auth = predicates
-web.core.namespace['web'].user = user
-
+web.core.namespace['web']['auth'] = predicates
+web.core.namespace['web']['user'] = user
 
 def authenticate(identifier, password=None, force=False):
     """Authenticate a user.
@@ -35,10 +31,9 @@ def authenticate(identifier, password=None, force=False):
     
     if force:
         result = (identifier, config.lookup(identifier))
-    
     else:
         result = config.authenticate(identifier, password)
-        
+    
     if result is None or result[1] is None:
         log.debug('Authentication failed: %r', result)
         return False
@@ -84,7 +79,7 @@ def authorize(predicate):
         @functools.wraps(func)
         def wrapper(*args, **kw):
             if not bool(predicate):
-                raise webob.exc.HTTPUnauthorized()
+                raise web.core.http.HTTPUnauthorized()
             
             return func(*args, **kw)
         
